We are working on a Github page with more info at: https://tsaopy.github.io/.

We have a Zenodo DOI for referencing the repository

[![DOI](https://zenodo.org/badge/427913804.svg)](https://zenodo.org/badge/latestdoi/427913804)
